diff --git a/src/plugins/KDESupport/CMakeLists.txt b/src/plugins/KDESupport/CMakeLists.txt
new file mode 100644
index 000000000..04b7bf258
--- /dev/null
+++ b/src/plugins/KDESupport/CMakeLists.txt
@@ -0,0 +1,15 @@
+set(KDESupport_SRCS
+ kdesupportplugin.cpp
+ kwalletpasswordbackend.cpp
+)
+
+ecm_create_qm_loader(KDESupport_SRCS falkon_kdesupport_qt)
+
+set(KDESupport_RSCS
+ kdesupport.qrc
+)
+qt5_add_resources(RSCS ${KDESupport_RSCS})
+
+add_library(KDESupport MODULE ${KDESupport_SRCS} ${RSCS})
+install(TARGETS KDESupport DESTINATION ${FALKON_INSTALL_PLUGINDIR})
+target_link_libraries(KDESupport FalkonPrivate KF5::Wallet)
diff --git a/src/plugins/KWalletPasswords/Messages.sh b/src/plugins/KDESupport/Messages.sh
similarity index 59%
rename from src/plugins/KWalletPasswords/Messages.sh
rename to src/plugins/KDESupport/Messages.sh
index 512d732f1..8f66bdb5d 100644
--- a/src/plugins/KWalletPasswords/Messages.sh
+++ b/src/plugins/KDESupport/Messages.sh
@@ -1,2 +1,2 @@
#! /bin/sh
-$EXTRACT_TR_STRINGS `find . -name '*.cpp' -o -name '*.h' -o -name '*.ui'` -o $podir/falkon_kwalletpasswords_qt.pot
+$EXTRACT_TR_STRINGS `find . -name '*.cpp' -o -name '*.h' -o -name '*.ui'` -o $podir/falkon_kdesupport_qt.pot
diff --git a/src/plugins/KDESupport/data/icon.svg b/src/plugins/KDESupport/data/icon.svg
new file mode 100644
index 000000000..b61d41163
--- /dev/null
+++ b/src/plugins/KDESupport/data/icon.svg
@@ -0,0 +1,132 @@
+
+
diff --git a/src/plugins/KDESupport/kdesupport.qrc b/src/plugins/KDESupport/kdesupport.qrc
new file mode 100644
index 000000000..05b7a8c44
--- /dev/null
+++ b/src/plugins/KDESupport/kdesupport.qrc
@@ -0,0 +1,6 @@
+
+
+ metadata.desktop
+ data/icon.svg
+
+
diff --git a/src/plugins/KWalletPasswords/kwalletpasswordbackend.h b/src/plugins/KDESupport/kwalletpasswordbackend.h
similarity index 96%
rename from src/plugins/KWalletPasswords/kwalletpasswordbackend.h
rename to src/plugins/KDESupport/kwalletpasswordbackend.h
index 2752f0f5a..a0a58f91f 100644
--- a/src/plugins/KWalletPasswords/kwalletpasswordbackend.h
+++ b/src/plugins/KDESupport/kwalletpasswordbackend.h
@@ -1,5 +1,5 @@
/* ============================================================
-* KWalletPasswords - KWallet support plugin for Falkon
+* KDESupport - KDE support plugin for Falkon
* Copyright (C) 2013-2014 David Rosca
*
* This program is free software: you can redistribute it and/or modify
diff --git a/src/plugins/KDESupport/metadata.desktop b/src/plugins/KDESupport/metadata.desktop
new file mode 100644
index 000000000..4be6e4025
--- /dev/null
+++ b/src/plugins/KDESupport/metadata.desktop
@@ -0,0 +1,11 @@
+[Desktop Entry]
+Name=KDE Support
+Comment=Provides support for storing passwords in KWallet
+
+Icon=:kdesupport/data/icon.svg
+Type=Service
+
+X-Falkon-Author=David Rosca
+X-Falkon-Email=nowrep@gmail.com
+X-Falkon-Version=0.2.0
+X-Falkon-Settings=false
diff --git a/src/plugins/KWalletPasswords/CMakeLists.txt b/src/plugins/KWalletPasswords/CMakeLists.txt
deleted file mode 100644
index 6b3bba20f..000000000
--- a/src/plugins/KWalletPasswords/CMakeLists.txt
+++ /dev/null
@@ -1,16 +0,0 @@
-set( KWalletPasswords_SRCS
- kwalletplugin.cpp
- kwalletpasswordbackend.cpp
- )
-
-ecm_create_qm_loader( KWalletPasswords_SRCS falkon_kwalletpasswords_qt )
-
-set( KWalletPasswords_RSCS
- kwalletpasswords.qrc
- )
-qt5_add_resources(RSCS ${KWalletPasswords_RSCS})
-
-add_library(KWalletPasswords MODULE ${KWalletPasswords_SRCS} ${RSCS})
-install(TARGETS KWalletPasswords DESTINATION ${FALKON_INSTALL_PLUGINDIR})
-target_link_libraries(KWalletPasswords FalkonPrivate KF5::Wallet)
-
diff --git a/src/plugins/KWalletPasswords/data/icon.png b/src/plugins/KWalletPasswords/data/icon.png
deleted file mode 100644
index cc1f458d7..000000000
Binary files a/src/plugins/KWalletPasswords/data/icon.png and /dev/null differ
diff --git a/src/plugins/KWalletPasswords/kwalletpasswords.qrc b/src/plugins/KWalletPasswords/kwalletpasswords.qrc
deleted file mode 100644
index 6cf9605e1..000000000
--- a/src/plugins/KWalletPasswords/kwalletpasswords.qrc
+++ /dev/null
@@ -1,6 +0,0 @@
-
-
- metadata.desktop
- data/icon.png
-
-
diff --git a/src/plugins/KWalletPasswords/metadata.desktop b/src/plugins/KWalletPasswords/metadata.desktop
deleted file mode 100644
index bdc122876..000000000
--- a/src/plugins/KWalletPasswords/metadata.desktop
+++ /dev/null
@@ -1,31 +0,0 @@
-[Desktop Entry]
-Name=KWallet Passwords
-Name[ca]=Contrasenyes del KWallet
-Name[ca@valencia]=Contrasenyes del KWallet
-Name[en_GB]=KWallet Passwords
-Name[fi]=KWallet-salasanat
-Name[it]=Password di KWallet
-Name[nl]=Wachtwoorden in KWallet
-Name[pt]=Senhas do KWallet
-Name[sv]=Plånbokens lösenord
-Name[uk]=Паролі KWallet
-Name[x-test]=xxKWallet Passwordsxx
-Comment=Provides support for storing passwords in KWallet
-Comment[ca]=Proporciona suport per emmagatzemar contrasenyes al KWallet
-Comment[ca@valencia]=Proporciona suport per emmagatzemar contrasenyes al KWallet
-Comment[en_GB]=Provides support for storing passwords in KWallet
-Comment[fi]=Tarjoaa tuen salasanojen tallentamiseksi KWalletiin
-Comment[it]=Fornisce un supporto all'immagazzinamento di password in KWallet
-Comment[nl]=Biedt ondersteuning voor opslaan wachtwoorden in KWallet
-Comment[pt]=Oferece o suporte para guardar as senhas no KWallet
-Comment[sv]=Tillhandahåller stöd för att lagra lösenord i plånboken
-Comment[uk]=Забезпечує підтримку зберігання паролів у KWallet
-Comment[x-test]=xxProvides support for storing passwords in KWalletxx
-
-Icon=:kwp/data/icon.png
-Type=Service
-
-X-Falkon-Author=David Rosca
-X-Falkon-Email=nowrep@gmail.com
-X-Falkon-Version=0.1.2
-X-Falkon-Settings=false
diff --git a/src/plugins/KWalletPasswords/kwalletplugin.cpp b/src/plugins/KDESupport/kdesupportplugin.cpp
similarity index 80%
rename from src/plugins/KWalletPasswords/kwalletplugin.cpp
rename to src/plugins/KDESupport/kdesupportplugin.cpp
index cc37ff882..d47e3fd60 100644
--- a/src/plugins/KWalletPasswords/kwalletplugin.cpp
+++ b/src/plugins/KDESupport/kdesupportplugin.cpp
@@ -1,5 +1,5 @@
/* ============================================================
* KWalletPasswords - KWallet support plugin for Falkon
* Copyright (C) 2013-2018 David Rosca
*
* This program is free software: you can redistribute it and/or modify
@@ -15,7 +15,7 @@
* You should have received a copy of the GNU General Public License
* along with this program. If not, see .
* ============================================================ */
-#include "kwalletplugin.h"
+#include "kdesupportplugin.h"
#include "kwalletpasswordbackend.h"
#include "pluginproxy.h"
#include "browserwindow.h"
@@ -25,18 +25,18 @@
#include "passwordmanager.h"
#include "desktopfile.h"
-KWalletPlugin::KWalletPlugin()
+KDESupportPlugin::KDESupportPlugin()
: QObject()
, m_backend(0)
{
}
-DesktopFile KWalletPlugin::metaData() const
+DesktopFile KDESupportPlugin::metaData() const
{
- return DesktopFile(QSL(":kwp/metadata.desktop"));
+ return DesktopFile(QSL(":kdesupport/metadata.desktop"));
}
-void KWalletPlugin::init(InitState state, const QString &settingsPath)
+void KDESupportPlugin::init(InitState state, const QString &settingsPath)
{
Q_UNUSED(state);
Q_UNUSED(settingsPath);
@@ -45,13 +45,13 @@ void KWalletPlugin::init(InitState state, const QString &settingsPath)
mApp->autoFill()->passwordManager()->registerBackend(QSL("KWallet"), m_backend);
}
-void KWalletPlugin::unload()
+void KDESupportPlugin::unload()
{
mApp->autoFill()->passwordManager()->unregisterBackend(m_backend);
delete m_backend;
}
-bool KWalletPlugin::testPlugin()
+bool KDESupportPlugin::testPlugin()
{
// Require the version that the plugin was built with
return (Qz::VERSION == QLatin1String(FALKON_VERSION));
@@ -1,5 +1,5 @@
/* ============================================================
-* KWalletPasswords - KWallet support plugin for Falkon
+* KDESupport - KDE support plugin for Falkon
* Copyright (C) 2013-2018 David Rosca
*
diff --git a/src/plugins/KWalletPasswords/kwalletplugin.h b/src/plugins/KDESupport/kdesupportplugin.h
similarity index 80%
rename from src/plugins/KWalletPasswords/kwalletplugin.h
rename to src/plugins/KDESupport/kdesupportplugin.h
index e358623e5..e8631bb58 100644
--- a/src/plugins/KWalletPasswords/kwalletplugin.h
+++ b/src/plugins/KDESupport/kdesupportplugin.h
@@ -1,5 +1,5 @@
/* ============================================================
* KWalletPasswords - KWallet support plugin for Falkon
* Copyright (C) 2013-2018 David Rosca
*
* This program is free software: you can redistribute it and/or modify
@@ -15,21 +15,21 @@
* You should have received a copy of the GNU General Public License
* along with this program. If not, see .
* ============================================================ */
-#ifndef KWALLETPLUGIN_H
-#define KWALLETPLUGIN_H
+#ifndef KDESUPPORTPLUGIN_H
+#define KDESUPPORTPLUGIN_H
#include "plugininterface.h"
class KWalletPasswordBackend;
-class KWalletPlugin : public QObject, public PluginInterface
+class KDESupportPlugin : public QObject, public PluginInterface
{
Q_OBJECT
Q_INTERFACES(PluginInterface)
- Q_PLUGIN_METADATA(IID "Falkon.Browser.plugin.KWalletPasswords")
+ Q_PLUGIN_METADATA(IID "Falkon.Browser.plugin.KDESupport")
public:
- explicit KWalletPlugin();
+ explicit KDESupportPlugin();
DesktopFile metaData() const override;
void init(InitState state, const QString &settingsPath) override;
@@ -41,4 +41,4 @@ private:
};
-#endif // KWALLETPLUGIN_H
+#endif // KDESUPPORTPLUGIN_H
@@ -1,5 +1,5 @@
/* ============================================================
-* KWalletPasswords - KWallet support plugin for Falkon
+* KDESupport - KDE support plugin for Falkon
* Copyright (C) 2013-2018 David Rosca
*
diff --git a/src/plugins/KWalletPasswords/kwalletpasswordbackend.cpp b/src/plugins/KDESupport/kwalletpasswordbackend.cpp
similarity index 97%
rename from src/plugins/KWalletPasswords/kwalletpasswordbackend.cpp
rename to src/plugins/KDESupport/kwalletpasswordbackend.cpp
index fe4caeb04..ba903bf21 100644
--- a/src/plugins/KWalletPasswords/kwalletpasswordbackend.cpp
+++ b/src/plugins/KDESupport/kwalletpasswordbackend.cpp
@@ -1,5 +1,5 @@
/* ============================================================
* KWalletPasswords - KWallet support plugin for Falkon
* Copyright (C) 2013-2018 David Rosca
*
* This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
* along with this program. If not, see .
* ============================================================ */
#include "kwalletpasswordbackend.h"
-#include "kwalletplugin.h"
+#include "kdesupportplugin.h"
#include "mainapplication.h"
#include "browserwindow.h"
@@ -48,7 +48,7 @@ KWalletPasswordBackend::KWalletPasswordBackend()
QString KWalletPasswordBackend::name() const
{
- return KWalletPlugin::tr("KWallet");
+ return KDESupportPlugin::tr("KWallet");
}
QVector KWalletPasswordBackend::getEntries(const QUrl &url)
@@ -1,5 +1,5 @@
/* ============================================================
-* KWalletPasswords - KWallet support plugin for Falkon
+* KDESupport - KDE support plugin for Falkon
* Copyright (C) 2013-2018 David Rosca
*